---
name: Documentation
about: Recommend an update to the documentation
title: ''
labels: 'Documentation'
assignees: ''

---

## Description 

Please describe the issue or enhancement you want to report. Provide as much detail as possible to help us understand and address it.

## Documentation type 

Tell us which of the four Diátaxis documentation types this issue or enhancement relates to:

- Tutorial
- How-to guide  
- Technical reference / Math Spec
- Explanation

## Affected area(s)

For the selected documentation type, tell us what specific area(s) this issue relates to. Provide titles, page numbers, URLs or other locators. 

## Expected or desired behavior

Tell us what you expected to see in the documentation, or how you think it could be improved. For enhancements, describe the improvement you think could be made.

## Additional context

Provide any other context or screenshots that would help us understand the issue or enhancement.

## Possible solutions (optional)

If you have any suggestions for how to address the issue or implement the enhancement, provide them here. We appreciate any insights you have!

## Who should review this?  

Tag any individuals, teams, or roles that would likely need to review or address this issue for the specified documentation type.

We will do our best to direct this to the appropriate people. Thank you for your feedback!
